<?php

/**
 * @file
 * Enables modules and site configuration for a standard site installation.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\rwprofile\Form\ModuleConfigureForm;

/**
 * Implements hook_form_FORM_ID_alter() for install_configure_form().
 *
 * Allows the profile to alter the site configuration form.
 */
function rwprofile_form_install_configure_form_alter(array &$form, FormStateInterface $form_state): void {
  $form['site_information']['site_name']['#placeholder'] = 'RW Drupal';
}

/**
 * Implements hook_install_tasks().
 */
function rwprofile_install_tasks(array &$install_state): array {
  $tasks = [];

  if (empty($install_state['config_install_path'])) {
    $tasks['rwprofile_module_configure_form'] = [
      'display_name' => t('Configure additional modules'),
      'type' => 'form',
      'function' => ModuleConfigureForm::class,
    ];
    $tasks['rwprofile_module_install'] = [
      'display_name' => t('Install additional modules'),
      'type' => 'batch',
    ];
  }
  $tasks['rwprofile_finish_installation'] = [
    'display_name' => t('Finish installation'),
  ];

  return $tasks;
}

/**
 * Installs the additional modules in a batch.
 *
 * @param array $install_state
 *   The install state.
 *
 * @return array
 *   A batch array to execute.
 */
function rwprofile_module_install(array &$install_state): array {
  return $install_state['rwprofile_install_batch'] ?? [];
}

/**
 * Finish RW Drupal installation process.
 *
 * @param array $install_state
 *   The install state.
 *
 * @throws \Drupal\Core\Entity\EntityStorageException
 */
function rwprofile_finish_installation(array &$install_state): void {

}
